## ---- echo=FALSE, include=FALSE-----------------------------------------------
library(rgho)
library(knitr)

## ---- echo=FALSE--------------------------------------------------------------
kable(
      get_gho_values(dimension = "COUNTRY")
  )

